@@ -1,11 +1,15 @@
 package App::Midgen;
 
-use v5.10;
+use 5.008001;
+use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3, TRUE => 1,
+	FALSE => 0,};
+
 use Moo;
 with qw(
 	App::Midgen::Role::Options
 	App::Midgen::Role::Attributes
 	App::Midgen::Role::AttributesX
+	App::Midgen::Role::InDistribution
 	App::Midgen::Role::TestRequires
 	App::Midgen::Role::UseOk
 	App::Midgen::Role::Eval
@@ -14,17 +18,16 @@ with qw(
 	App::Midgen::Role::UseModule
 );
 
-# turn off experimental warnings
-no if $] > 5.017010, warnings => 'experimental::smartmatch';
-
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
+use version;
+our $VERSION = '0.30';
+$VERSION = eval $VERSION;    ## no critic
 
-our $VERSION = '0.28';
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
-use Cwd qw(cwd);
+use Cwd qw(getcwd);
 use Data::Printer {caller_info => 1, colored => 1,};
 use File::Find qw(find);
 use File::Spec;
@@ -33,15 +36,13 @@ use MetaCPAN::API;
 use Module::CoreList;
 use PPI;
 use Perl::PrereqScanner;
-use Scalar::Util qw(looks_like_number);
 use Term::ANSIColor qw( :constants colored colorstrip );
 use Try::Tiny;
-
-use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
+use Tie::Static qw(static);
 use version;
 
 # stop rlib from Fing all over cwd
-our $Working_Dir = cwd();
+our $Working_Dir = getcwd();
 our $Min_Version = 0;
 
 
@@ -58,51 +59,53 @@ sub run {
 
 	$self->find_required_modules();
 
-	p $self->{modules} if ($self->verbose == TWO);
-
-	$self->remove_noisy_children($self->{package_requires})
-		if $self->experimental;
-	$self->remove_twins($self->{package_requires}) if $self->experimental;
-
-
-# Run a second time if we found any twins, this will sort out twins and triplets etc
-	$self->remove_noisy_children($self->{package_requires})
-		if $self->found_twins;
+#	p $self->{modules} if ($self->verbose == TWO);
 
 	$self->find_required_test_modules();
 
-	# Now we have switched to MetaCPAN-Api we can hunt for noisy children in test requires
-	if ($self->experimental) {
-		p $self->{test_requires} if $self->debug;
-		$self->remove_noisy_children($self->{test_requires});
-		foreach my $module (keys %{$self->{test_requires}}) {
-			if ($self->{package_requires}{$module}) {
-				warn $module if $self->debug;
-				try {
-					delete $self->{test_requires}{$module};
-				};
-			}
-		}
-		p $self->{test_requires} if $self->debug;
 
+	# Now we have switched to MetaCPAN-Api we can hunt for noisy children in tests
+	if ($self->experimental) {
+
+		$self->remove_noisy_children($self->{RuntimeRequires});
+		$self->remove_twins($self->{RuntimeRequires});
+
+		# Run a second time if we found any twins, this will sort out twins and triplets etc
+		$self->remove_noisy_children($self->{RuntimeRequires})
+			if $self->found_twins;
+
+		foreach (qw( TestRequires TestSuggests DevelopRequires )) {
+
+			p $self->{$_} if $self->debug;
+			$self->remove_noisy_children($self->{$_});
+			foreach my $module (keys %{$self->{$_}}) {
+				if ($self->{RuntimeRequires}{$module}) {
+					warn $module if $self->debug;
+					try {
+						delete $self->{$_}{$module};
+					};
+				}
+			}
+			p $self->{$_} if $self->debug;
+		}
 	}
 
+
 	# display chosen output format
 	$self->output_header();
 
-	$self->output_main_body('requires',      $self->{package_requires});
-			if ($self->format =~ /cpanfile|metajson/) {
-				$self->output_main_body('runtime_recommends', $self->{runtime_recommends});
-			}
-
-	$self->output_main_body('test_requires', $self->{test_requires});
-	$self->output_main_body('recommends',    $self->{recommends});
-	$self->output_main_body('test_develop',  $self->{test_develop})
-		if $self->develop;
+	$self->output_main_body('RuntimeRequires',   $self->{RuntimeRequires});
+	$self->output_main_body('RuntimeRecommends', $self->{RuntimeRecommends})
+		if $self->meta2;
+	$self->output_main_body('TestRequires', $self->{TestRequires});
+	$self->output_main_body('TestSuggests', $self->{TestSuggests});
+	$self->output_main_body('Close', {});
+	$self->output_main_body('DevelopRequires', $self->{DevelopRequires})
+		if $self->meta2;
 
 	$self->output_footer();
 
-	p $self->{modules} if $self->debug;
+	p $self->{modules} if ($self->verbose == TWO);
 
 	return;
 }
@@ -113,7 +116,7 @@ sub run {
 sub _initialise {
 	my $self = shift;
 
-# let's give Output a copy, to stop it being F'up as well, suspect Tiny::Path as-well rlib
+	# let's give Output a copy, to stop it being F'up as well, suspect Tiny::Path as-well rlib
 	warn 'working in dir: ' . $Working_Dir if $self->debug;
 
 	return;
@@ -147,7 +150,7 @@ sub first_package_name {
 	};
 
 	# I still want to see package name even though infile sets verbose = 0
-	say 'Package: ' . $self->distribution_name
+	print 'Package: ' . $self->distribution_name . "\n"
 		if $self->verbose
 		or $self->format eq 'infile';
 
@@ -159,9 +162,9 @@ sub first_package_name {
 sub _find_package_names {
 	my $self     = shift;
 	my $filename = $_;
-	state $files_checked;
+	static \my $files_checked;
 	if (defined $files_checked) {
-		return if $files_checked >= THREE and not $self->min_ver_fast;
+		return if $files_checked >= THREE;
 	}
 
 	# Only check in pm files
@@ -170,19 +173,6 @@ sub _find_package_names {
 	# Load a Document from a file
 	$self->_set_ppi_document(PPI::Document->new($filename));
 
-	try {
-		if ($self->min_ver_fast) {
-
-			# say 'running fast';
-			$self->min_version($filename);
-		}
-		else {
-
-			# say 'running slow';
-			$self->min_version();    # if not $self->min_ver_fast;
-		}
-	};
-
 	# Extract package names
 	push @{$self->package_names},
 		$self->ppi_document->find_first('PPI::Statement::Package')->namespace;
@@ -199,7 +189,8 @@ sub find_required_modules {
 	my $self = shift;
 
 	my @posiable_directories_to_search
-		= map { File::Spec->catfile($Working_Dir, $_) } qw( script bin lib );
+		= map { File::Spec->catfile($Working_Dir, $_) }
+		qw( bin share script lib );
 
 	my @directories_to_search = ();
 	foreach my $directory (@posiable_directories_to_search) {
@@ -255,44 +246,23 @@ sub find_required_test_modules {
 # _find_makefile_requires
 #######
 sub _find_makefile_requires {
-	my $self      = shift;
-	my $filename  = $_;
-	my $is_script = 0;
+	my $self     = shift;
+	my $filename = $_;
 
-	given ($filename) {
-		when (m/[.]pm$/) {
-			say 'looking for requires in (.pm)-> ' . $filename
-				if $self->verbose >= TWO;
-		}
-		when (m/[.]psgi$/) {
-			say 'looking for requires in (.psgi)-> ' . $filename
-				if $self->verbose >= TWO;
-		}
-		when (m/[.]\w{2,4}$/) {
-			say 'rejecting ' . $filename if $self->verbose >= TWO;
-			return;
-		}
-		default { return if not $self->_is_perlfile($filename); $is_script = 1; }
-	}
-	try {
-		if ($self->min_ver_fast) {
-			$self->min_version($filename);
-		}
-		else {
-			$self->min_version() if $is_script;
-		}
-	};
+	return if $self->is_perlfile($filename) eq FALSE;
 
 	my $relative_dir = $File::Find::dir;
 	$relative_dir =~ s/$Working_Dir//;
 	$self->_set_looking_infile(File::Spec->catfile($relative_dir, $filename));
 	$self->_set_ppi_document(PPI::Document->new($filename));
 
+	$self->min_version();
+
 	# do extra test early check for use_module before hand
-	$self->xtests_use_module('runtime_recommends');
+	$self->xtests_use_module('RuntimeRecommends');
 
 	# ToDo add eval/try here -> prereqs { runtime { suggests or recommends {...}}}
-	$self->xtests_eval('runtime_recommends');
+	$self->xtests_eval('RuntimeRecommends');
 
 	my $prereqs = $self->scanner->scan_ppi_document($self->ppi_document);
 	my @modules = $prereqs->required_modules;
@@ -304,14 +274,13 @@ sub _find_makefile_requires {
 
 	$self->{skip_not_mcpan_stamp} = 0;
 
-	if (/^Dist::Zilla::Role::PluginBundle/ ~~ @modules) {
+	if (grep { $_ =~ m/^Dist::Zilla::Role::PluginBundle/ } @modules) {
 
 		$self->{skip_not_mcpan_stamp} = 1;
 
 		my $ppi_tqs = $self->ppi_document->find('PPI::Token::Quote::Single');
 		if ($ppi_tqs) {
 
-			# my @modules;
 			foreach my $include (@{$ppi_tqs}) {
 
 				my $module = $include->content;
@@ -319,7 +288,8 @@ sub _find_makefile_requires {
 				$module =~ s/[']$//;
 
 				next if $module =~ m/^Dist::Zilla::Role::PluginBundle/;
-				next if $module =~ m{[.|$|\\|/|-|%|@|]};
+				next if $module =~ m{\A[-|:|\d|a-z]};
+				next if $module =~ m{[.|$|\\|/|\-|\[|%|@|]};
 				next if $module eq NONE;
 
 				push @modules, 'Dist::Zilla::Plugin::' . $module;
@@ -327,45 +297,11 @@ sub _find_makefile_requires {
 		}
 	}
 
-	$self->_process_found_modules('package_requires', \@modules);
+	$self->_process_found_modules('RuntimeRequires', \@modules,
+		'Perl::PrereqScanner');
 	return;
 }
 
-########
-# is this a perl file
-#######
-sub _is_perlfile {
-	my $self     = shift;
-	my $filename = shift;
-
-	$self->_set_ppi_document(PPI::Document->new($filename));
-	my $ppi_tc = $self->ppi_document->find('PPI::Token::Comment');
-
-	my $a_pl_file = 0;
-
-	if ($ppi_tc) {
-
-		# check first token-comment for a she-bang
-		$a_pl_file = 1 if $ppi_tc->[0]->content =~ m/^#!.*perl.*$/;
-	}
-
-	if ($self->ppi_document->find('PPI::Statement::Package') || $a_pl_file) {
-		if ($self->verbose >= TWO) {
-
-			print "looking for requires in (package) -> "
-				if $self->ppi_document->find('PPI::Statement::Package');
-			print "looking for requires in (shebang) -> "
-				if $ppi_tc->[0]->content =~ /perl/;
-			say $filename ;
-		}
-		return 1;
-	}
-	else {
-		return 0;
-	}
-
-}
-
 
 #######
 # _find_makefile_test_requires
@@ -373,35 +309,38 @@ sub _is_perlfile {
 sub _find_makefile_test_requires {
 	my $self       = shift;
 	my $directorie = shift;
+	my $filename   = $_;
+
 	##p $directorie;
-	my $prerequisites
-		= ($directorie =~ m/xt$/) ? 'test_develop' : 'test_requires';
-	$self->_set_xtest('test_develop') if $directorie =~ m/xt$/;
+	my $phase_relationship
+		= ($directorie =~ m/xt$/) ? 'DevelopRequires' : 'TestSuggests';
+	$self->_set_xtest(TRUE) if $directorie =~ m/xt$/;
 
-	my $filename = $_;
-	return if $filename !~ /[.]t|pm$/sxm;
-
-	say 'looking for test_requires in: ' . $filename if $self->verbose >= TWO;
+	return if $self->is_perlfile($filename) eq FALSE;
 
 	my $relative_dir = $File::Find::dir;
 	$relative_dir =~ s/$Working_Dir//;
 	$self->_set_looking_infile(File::Spec->catfile($relative_dir, $filename));
 
+	$self->min_version() if not $self->experimental;
+
 	# Load a Document from a file and check use and require contents
 	$self->_set_ppi_document(PPI::Document->new($filename));
 
 	# do extra test early check for Test::Requires before hand
-	$self->xtests_test_requires();
+	$self->xtests_test_requires($phase_relationship);
 
 	# do extra test early check for use_ok in BEGIN blocks before hand
-	$self->xtests_use_ok();
+	$self->xtests_use_ok($phase_relationship);
 
 	# do extra test early to identify eval before hand
-	$self->xtests_eval('test_requires');
+	$self->xtests_eval($phase_relationship);
 
 	# do extra test early check for use_module before hand
-	$self->xtests_use_module('test_requires');
+	$self->xtests_use_module($phase_relationship);
 
+
+	# let's run p-ps for the rest
 	my $prereqs = $self->scanner->scan_ppi_document($self->ppi_document);
 	my @modules = $prereqs->required_modules;
 
@@ -413,17 +352,19 @@ sub _find_makefile_test_requires {
 	}
 
 	if (scalar @modules > 0) {
-		if ($self->format =~ /cpanfile|metajson/) {
-			if ($self->xtest eq 'test_requires') {
-				$self->_process_found_modules('test_requires', \@modules);
-			}
-			elsif ($self->develop && $self->xtest eq 'test_develop') {
-				$self->_process_found_modules('test_develop', \@modules);
-			}
+		if ($self->xtest) {
+			$self->_process_found_modules($phase_relationship, \@modules,
+				'Perl::PrereqScanner')
+				if $self->meta2;
+			$self->_process_found_modules('DevelopRequires', \@modules,
+				'Perl::PrereqScanner')
+				if not $self->meta2;
 		}
 		else {
-			$self->_process_found_modules('test_requires', \@modules);
+			$self->_process_found_modules('TestRequires', \@modules,
+				'Perl::PrereqScanner');
 		}
+
 	}
 
 	return;
@@ -434,9 +375,10 @@ sub _find_makefile_test_requires {
 # composed method - _process_found_modules
 #######
 sub _process_found_modules {
-	my $self         = shift;
-	my $require_type = shift;
-	my $modules_ref  = shift;
+	my $self          = shift;
+	my $require_type  = shift;
+	my $modules_ref   = shift;
+	my $extra_scanner = shift || 'none';
 
 	foreach my $module (@{$modules_ref}) {
 
@@ -449,53 +391,56 @@ sub _process_found_modules {
 		# let's show every thing we can find infile
 		if ($self->format ne 'infile') {
 
-			my $distribution_name = $self->distribution_name // 'm/t';
-			given ($module) {
-				when (/perl/sxm) {
+			my $distribution_name = $self->distribution_name || 'm/t';
 
-					# ignore perl we will get it from minperl required
-					next;
-				}
-				when (/\A\Q$distribution_name\E/sxm) {
+			if ($module =~ /perl/sxm) {
 
-					# don't include our own packages here
-					next;
-				}
-				when (/^t::/sxm) {
+				# ignore perl we will get it from minperl required
+				next;
+			}
+			elsif ($module =~ /\A\Q$distribution_name\E/sxm) {
 
-					# don't include our own test packages here
-					next;
-				}
+				# don't include our own packages here
+				next;
+			}
+			elsif ($module =~ /^t::/sxm) {
 
-				when (/Mojo/sxm) {
-					if ($self->experimental) {
-						if ($self->_check_mojo_core($module, $require_type)) {
-							if (not $self->quiet) {
-								print BRIGHT_BLACK;
-								say 'swapping out ' . $module . ' for Mojolicious';
-								print CLEAR;
-							}
-							next;
+				# don't include our own test packages here
+				next;
+			}
+
+			elsif ($module =~ /Mojo/sxm) {
+				if ($self->experimental) {
+					if ($self->_check_mojo_core($module, $require_type)) {
+						if (not $self->quiet) {
+							print BRIGHT_BLACK;
+							print "swapping out $module for Mojolicious\n";
+							print CLEAR;
 						}
+						next;
 					}
 				}
-				when (/^Padre/sxm) {
+			}
+			elsif ($module =~ /^Padre/sxm) {
 
-					# mark all Padre core as just Padre, for plugins
-					$module = 'Padre';
-				}
+				# mark all Padre core as just Padre only, for plugins
+				$module = 'Padre';
 			}
 		}
 
 		# lets keep track of how many times a module include is found
 		$self->{modules}{$module}{count} += 1;
+
 		push @{$self->{modules}{$module}{infiles}},
-			[$self->looking_infile(), $self->{found_version}{$module} // 0];
+			[
+			$self->looking_infile(), $self->{found_version}{$module} || 0,
+			$extra_scanner
+			];
 
 		# don't process already found modules
-		p $self->{modules}{$module}{location} if $self->debug;
+		p $self->{modules}{$module}{prereqs} if $self->debug;
 
-		next if defined $self->{modules}{$module}{location};
+		next if defined $self->{modules}{$module}{prereqs};
 		p $module if $self->debug;
 
 		# add skip for infile as we don't need to get v-string from metacpan-api
@@ -517,43 +462,41 @@ sub _store_modules {
 	$self->_in_corelist($module)
 		if not defined $self->{modules}{$module}{corelist};
 	my $version = $self->get_module_version($module, $require_type);
-	given ($version) {
 
-		when ('!mcpan') {
-			$self->{$require_type}{$module} = colored('!mcpan', 'magenta')
-				if not $self->{skip_not_mcpan_stamp};
-			$self->{modules}{$module}{location} = $require_type;
-			$self->{modules}{$module}{version}  = '!mcpan';
+	if ($version eq '!mcpan') {
+		$self->{$require_type}{$module} = colored('!mcpan', 'magenta')
+			if not $self->{skip_not_mcpan_stamp};
+		$self->{modules}{$module}{prereqs} = $require_type;
+		$self->{modules}{$module}{version} = '!mcpan';
+	}
+	elsif ($version eq 'core') {
+		$self->{$require_type}{$module} = $version if $self->core;
+		$self->{$require_type}{$module} = '0'      if $self->zero;
+		$self->{modules}{$module}{prereqs} = $require_type;
+		$self->{modules}{$module}{version} = $version if $self->core;
+	}
+	else {
+		if ($self->{modules}{$module}{corelist}) {
+
+			$self->{$require_type}{$module} = colored($version, 'bright_yellow')
+				if ($self->dual_life || $self->core);
+			$self->{modules}{$module}{prereqs} = $require_type
+				if ($self->dual_life || $self->core);
+			$self->{modules}{$module}{version} = $version
+				if ($self->dual_life || $self->core);
+			$self->{modules}{$module}{dual_life} = 1;
 		}
-		when ('core') {
-			$self->{$require_type}{$module} = $version if $self->core;
-			$self->{$require_type}{$module} = '0'      if $self->zero;
-			$self->{modules}{$module}{location} = $require_type;
-			$self->{modules}{$module}{version} = $version if $self->core;
-		}
-		default {
-			if ($self->{modules}{$module}{corelist}) {
+		else {
+			$self->{$require_type}{$module} = colored($version, 'yellow');
+			$self->{$require_type}{$module}
+				= colored(version->parse($version)->numify, 'yellow')
+				if $self->numify;
 
-				$self->{$require_type}{$module} = colored($version, 'bright_yellow')
-					if ($self->dual_life || $self->core);
-				$self->{modules}{$module}{location} = $require_type
-					if ($self->dual_life || $self->core);
-				$self->{modules}{$module}{version} = $version
-					if ($self->dual_life || $self->core);
-				$self->{modules}{$module}{dual_life} = 1;
-			}
-			else {
-				$self->{$require_type}{$module} = colored($version, 'yellow');
-				$self->{$require_type}{$module}
-					= colored(version->parse($version)->numify, 'yellow')
-					if $self->numify;
+			$self->{modules}{$module}{prereqs} = $require_type;
+			$self->{modules}{$module}{version} = $version;
 
-				$self->{modules}{$module}{location} = $require_type;
-				$self->{modules}{$module}{version}  = $version;
-
-				$self->{$require_type}{$module} = colored($version, 'bright_cyan')
-					if $self->{modules}{$module}{'distribution'};
-			}
+			$self->{$require_type}{$module} = colored($version, 'bright_cyan')
+				if $self->{modules}{$module}{'distribution'};
 		}
 	}
 	p $self->{modules}{$module} if $self->debug;
@@ -633,10 +576,10 @@ sub remove_noisy_children {
 						if (not $self->quiet) {
 							if ($self->verbose) {
 								print BRIGHT_BLACK;
-								say 'delete miscreant noisy child '
+								print 'delete miscreant noisy child '
 									. $child_name . ' => '
 									. $required_ref->{$child_name};
-								print CLEAR;
+								print CLEAR. "\n";
 							}
 						}
 						try {
@@ -644,7 +587,7 @@ sub remove_noisy_children {
 							splice @sorted_modules, $inner_index, 1;
 
 							unless ($self->{modules}{$parent_name}) {
-								$self->{modules}{$parent_name}{location} = 'expermental';
+								$self->{modules}{$parent_name}{prereqs} = 'expermental';
 								$self->{modules}{$parent_name}{version}
 									= $required_ref->{$parent_name};
 								$self->{modules}{$parent_name}{count} += 1;
@@ -718,7 +661,7 @@ sub remove_twins {
 					if ($self->verbose) {
 						print BRIGHT_BLACK;
 
-						# say 'i have found twins';
+						# stdout - 'i have found twins';
 						print $dum_name . ' => '
 							. $required_ref->{$sorted_modules[$n - 1]};
 						print BRIGHT_BLACK ' <-twins-> '
@@ -733,13 +676,13 @@ sub remove_twins {
 
 				$version = $self->get_module_version($dum_parient);
 
-				if (looks_like_number($version)) {
+				if (version::is_lax($version)) {
 
 					#Check parent version against a twins version
 					if ($version eq $required_ref->{$sorted_modules[$n]}) {
-						say $dum_parient . ' -> '
+						print $dum_parient . ' -> '
 							. $version
-							. ' is the parent of these twins'
+							. " is the parent of these twins\n"
 							if $self->verbose;
 						$required_ref->{$dum_parient} = $version;
 						$self->_set_found_twins(1);
@@ -762,7 +705,7 @@ sub _check_mojo_core {
 
 
 	my $mojo_module_ver;
-	state $mojo_ver;
+	static \my $mojo_ver;
 
 	if (not defined $mojo_ver) {
 		$mojo_ver = $self->get_module_version('Mojolicious');
@@ -774,8 +717,8 @@ sub _check_mojo_core {
 	if ($self->verbose) {
 		print BRIGHT_BLACK;
 
-		#say 'looks like we found another mojo core module';
-		say $mojo_module . ' version ' . $mojo_module_ver;
+		#stdout - 'looks like we found another mojo core module';
+		print "$mojo_module version $mojo_module_ver\n";
 		print CLEAR;
 	}
 
@@ -783,7 +726,7 @@ sub _check_mojo_core {
 		$self->{$require_type}{'Mojolicious'}
 			= colored($mojo_module_ver, 'bright_blue')
 			if !$self->{modules}{'Mojolicious'};
-		$self->{modules}{'Mojolicious'}{location} = $require_type;
+		$self->{modules}{'Mojolicious'}{prereqs} = $require_type;
 		return 1;
 	}
 	else {
@@ -806,7 +749,7 @@ sub get_module_version {
 	try {
 		$module =~ s/::/-/g;
 
-# quick n dirty, get version number if module is classed as a distribution in metacpan
+		# quick n dirty, get version number if module is classed as a distribution in metacpan
 		my $mod = $self->mcpan->release(distribution => $module);
 
 		#p $mod;
@@ -853,9 +796,9 @@ sub get_module_version {
 		# a bit of de crappy-flying
 		# catch Test::Kwalitee::Extra 6e-06
 		print BRIGHT_BLACK;
-		say $module
+		print $module
 			. ' Unique Release Sequence Indicator NOT! -> '
-			. $cpan_version
+			. $cpan_version . "\n"
 			if $self->verbose >= 1;
 		print CLEAR;
 		$cpan_version = version->parse($cpan_version)->numify;
@@ -878,18 +821,18 @@ sub mod_in_dist {
 	if ($module =~ /$dist/) {
 
 		print BRIGHT_BLACK;
-		say "module - $module  -> in dist - $dist" if $self->verbose >= 1;
+		print "module - $module  -> in dist - $dist\n" if $self->verbose >= 1;
 		print CLEAR;
 
 		# add dist to output hash so we can get rind of cruff later
 		if ($self->experimental) {
 
 			$self->{$require_type}{$dist} = colored($version, 'bright_cyan')
-				if not defined $self->{modules}{$module}{location};
+				if not defined $self->{modules}{$module}{prereqs};
 		}
 
 		$self->{$require_type}{$module} = colored($version, 'bright_cyan')
-			if not defined $self->{modules}{$module}{location};
+			if not defined $self->{modules}{$module}{prereqs};
 	}
 
 	return;
@@ -927,11 +870,11 @@ __END__
 
 =head1 NAME
 
-App::Midgen - Check B<requires> & B<test_requires> of your package for CPAN inclusion.
+App::Midgen - Check B<RuntimeRequires> & B<TestRequires> of your package for CPAN inclusion.
 
 =head1 VERSION
 
-This document describes App::Midgen version: 0.28
+This document describes App::Midgen version: 0.30
 
 =head1 SYNOPSIS
 
@@ -972,12 +915,12 @@ B<MetaCPAN Version Number Displayed>
 =back
 
 I<Food for thought, if we update our Modules,
- don't we want our users to use the current version,
- so should we not by default do the same with others Modules.
- Thus we always show the current version number, regardless.>
+don't we want our users to use the current version,
+so should we not by default do the same with others Modules.
+Thus we always show the current version number, regardless.>
 
 We also display some other complementary information relevant to this package
- and your chosen output format.
+and your chosen output format.
 
 For more info and sample output see L<wiki|https://github.com/kevindawson/App-Midgen/wiki>
 
@@ -996,7 +939,7 @@ Search for Includes B<use> and B<require> in package modules
 =item * find_required_test_modules
 
 Search for Includes B<use> and B<require> in test scripts,
- also B<use_ok>, I<plus some other patterns along the way.>
+also B<use_ok>, I<plus some other patterns along the way.>
 
 =item * first_package_name
 
