@@ -1,6 +1,7 @@
 package App::Midgen::Role::Attributes;
 
-use v5.10;
+use constant {TRUE => 1, FALSE => 0,};
+
 use Types::Standard qw( ArrayRef Bool Int Object Str);
 use Moo::Role;
 requires qw( experimental format );
@@ -10,7 +11,9 @@ requires qw( experimental format );
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.28';
+our $VERSION = '0.30';
+$VERSION = eval $VERSION; ## no critic
+
 use Carp;
 
 #######
@@ -27,7 +30,7 @@ has 'develop' => (
 sub _develop {
 	my $self = shift;
 
-	if ( $self->experimental && ( $self->format =~ m/cpanfile|metajson/) ) {
+	if ( $self->experimental && ( $self->format =~ m/cpanfile|metajson|dist/) ) {
 		return 1;
 	} else {
 		return 0;
@@ -49,6 +52,23 @@ has 'found_twins' => (
 	},
 );
 
+has 'meta2' => (
+	is      => 'ro',
+	isa     => Bool,
+	lazy    => 1,
+	builder => '_meta2',
+);
+
+sub _meta2 {
+	my $self = shift;
+
+	if ( $self->format =~ m/cpanfile|metajson|dist/ ) {
+		return 1;
+	} else {
+		return 0;
+	}
+}
+
 has 'numify' => (
 	is      => 'ro',
 	isa     => Bool,
@@ -71,10 +91,10 @@ has 'ppi_document' => (
 
 has 'xtest' => (
 	is      => 'rwp',
-	isa     => Str,
+	isa     => Bool,
 	lazy    => 1,
 	default => sub {
-		'test_requires';
+	return FALSE;
 	},
 );
 
@@ -101,7 +121,7 @@ App::Midgen::Role::Attributes - Package Attributes used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.28
+version: 0.30
 
 =head1 METHODS
 
