@@ -1,21 +1,18 @@
 package App::Midgen::Role::Output::MB;
 
-use v5.10;
-use Moo::Role;
+use constant {NONE => q{},};
 
-# turn off experimental warnings
-no if $] > 5.017010, warnings => 'experimental::smartmatch';
+use Moo::Role;
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.28';
-use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
+our $VERSION = '0.30';
+$VERSION = eval $VERSION;    ## no critic
+
+use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
-use Term::ANSIColor qw( :constants colored );
-use Data::Printer { caller_info => 1, colored => 1, };
-use constant { BLANK => q{ }, NONE => q{}, THREE => 3, };
 use File::Spec;
 
 #######
@@ -23,13 +20,11 @@ use File::Spec;
 #######
 sub header_mb {
 	my $self = shift;
-	my $package_name = shift // NONE;
+	my $package_name = shift || NONE;
 
-	if ( $package_name ne NONE ) {
-		print "\n";
+	if ($package_name ne NONE) {
 		$package_name =~ s{::}{-}g;
-		say '"dist_name" => "' . $package_name . q{",};
-		print "\n";
+		print "\n" . '"dist_name" => "' . $package_name . q{",} . "\n";
 	}
 
 	return;
@@ -41,23 +36,32 @@ sub body_mb {
 	my $self         = shift;
 	my $title        = shift;
 	my $required_ref = shift || return;
+
+	return if not %{$required_ref};
+
 	print "\n";
 
 	my $pm_length = 0;
-	foreach my $module_name ( sort keys %{$required_ref} ) {
-		if ( length $module_name > $pm_length ) {
+	foreach my $module_name (sort keys %{$required_ref}) {
+		if (length $module_name > $pm_length) {
 			$pm_length = length $module_name;
 		}
 	}
-	say q{"} . $title . '" => {';
 
-	foreach my $module_name ( sort keys %{$required_ref} ) {
+	$title =~ s/^Runtime//;
+	$title =~ s/^TestSuggests/recommends/;
+	$title =~ s/^Test/test_/;
+
+	print q{"} . $title . '" => {' . "\n";
+
+	foreach my $module_name (sort keys %{$required_ref}) {
 
 		my $sq_key = "\"$module_name\"";
-		printf "\t %-*s => \"%s\",\n", $pm_length + 2, $sq_key, $required_ref->{$module_name};
+		printf "\t %-*s => \"%s\",\n", $pm_length + 2, $sq_key,
+			$required_ref->{$module_name};
 
 	}
-	say '},';
+	print "},\n";
 
 	return;
 }
@@ -67,16 +71,15 @@ sub body_mb {
 sub footer_mb {
 	my $self = shift;
 
-	if ( defined -d File::Spec->catdir( $App::Midgen::Working_Dir, 'script' ) ) {
-		print "\n";
-		say '"script_files" => [';
+	if (defined -d File::Spec->catdir($App::Midgen::Working_Dir, 'script')) {
+		print "\n" . '"script_files" => [' . "\n";
 		print "\t\"script/...\"\n";
-		say '],';
-	} elsif ( defined -d File::Spec->catdir( $App::Midgen::Working_Dir, 'bin' ) ) {
-		print "\n";
-		say '"script_files" => [';
+		print "],\n";
+	}
+	elsif (defined -d File::Spec->catdir($App::Midgen::Working_Dir, 'bin')) {
+		print "\n" . '"script_files" => [' . "\n";
 		print "\t\"bin/...\"\n";
-		say '],';
+		print "],\n";
 	}
 
 	print "\n";
@@ -101,7 +104,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.28
+version: 0.30
 
 =head1 DESCRIPTION
 
