@@ -1,20 +1,19 @@
 package App::Midgen::Role::TestRequires;
 
-use v5.10;
+use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
+
 use Moo::Role;
-requires qw( ppi_document develop debug format xtest _process_found_modules );
+requires qw( ppi_document develop debug format xtest _process_found_modules meta2 );
 
 use PPI;
-
-use version 0.9902;
-use Try::Tiny 0.12;
+use Try::Tiny;
 use Data::Printer {caller_info => 1, colored => 1,};
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.28';
-use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
+our $VERSION = '0.30';
+$VERSION = eval $VERSION; ## no critic
 
 
 #######
@@ -22,6 +21,7 @@ use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
 #######
 sub xtests_test_requires {
 	my $self = shift;
+	my $phase_relationship = shift || NONE;
 
 	#  PPI::Statement::Include
 	#    PPI::Token::Word  	'use'
@@ -104,20 +104,16 @@ sub xtests_test_requires {
 											|| $element->isa('PPI::Token::Quote::Double')
 											|| $element->isa('PPI::Token::Quote::Single'))
 										{
-											my $version_number = $element->content;
-											$version_number =~ s/(?:'|")//g;
-											if ($version_number =~ m/\A(?:[0-9])/) {
+											my $version_string = $element->content;
+											$version_string =~ s/(?:'|")//g;
+											if ($version_string =~ m/\A(?:[0-9])/) {
 
-												try {
-													version->parse($version_number)->is_lax;
-												}
-												catch {
-													$version_number = 0 if $_;
-												};
-												warn 'found version string - ' . $version_number
+												$version_string = version::is_lax($version_string) ? $version_string : 0;
+
+												warn 'found version string - ' . $version_string
 													if $self->debug;
 												$self->{found_version}{$modules[$#modules]}
-													= $version_number;
+													= $version_string;
 											}
 										}
 									}
@@ -153,19 +149,14 @@ sub xtests_test_requires {
 	p @modules         if $self->debug;
 	p @version_strings if $self->debug;
 
-	# if we found a module, process it with the correct catogery
+	# if we found a module, process it with the correct phase-relationship
 	if (scalar @modules > 0) {
 
-		if ($self->format =~ /cpanfile|metajson/) {
-			if ($self->xtest eq 'test_requires') {
-				$self->_process_found_modules('recommends', \@modules);
-			}
-			elsif ($self->develop && $self->xtest eq 'test_develop') {
-				$self->_process_found_modules('test_develop', \@modules);
-			}
+		if ($self->meta2) {
+			$self->_process_found_modules($phase_relationship, \@modules, __PACKAGE__ );
 		}
 		else {
-			$self->_process_found_modules('recommends', \@modules);
+			$self->_process_found_modules('TestSuggests', \@modules, __PACKAGE__ );
 		}
 	}
 	return;
@@ -188,7 +179,7 @@ for methods in use L<Test::Requires> blocks, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.28
+version: 0.30
 
 =head1 METHODS
 
