@@ -1,26 +1,26 @@
 package App::Midgen::Role::UseModule;
 
-use v5.10;
-use Moo::Role;
-requires qw( ppi_document debug format xtest _process_found_modules develop );
-
-use PPI;
-
-use version 0.9902;
-use Data::Printer;    # caller_info => 1;
-use Try::Tiny;
-
-our $VERSION = '0.28';
 use constant {BLANK => q{ }, TRUE => 1, FALSE => 0, NONE => q{}, TWO => 2,
 	THREE => 3,};
 
+use Moo::Role;
+requires qw( ppi_document debug format xtest _process_found_modules develop meta2 );
+
+our $VERSION = '0.30';
+$VERSION = eval $VERSION; ## no critic
+
+use PPI;
+use Data::Printer;    # caller_info => 1;
+use Try::Tiny;
+use Tie::Static qw(static);
+
 
 #######
 # composed method - _xtests_in_single_quote
 #######
 sub xtests_use_module {
 	my $self = shift;
-	my $storage_location = shift;
+	my $phase_relationship = shift || NONE;
 
 	my @modules;
 	my @version_strings;
@@ -87,7 +87,7 @@ sub xtests_use_module {
 								my $ppi_sl = $chunk->{children}[$_]
 									if $chunk->{children}[$_]->isa('PPI::Structure::List');
 
-								say 'Option 1: use_module( M::N )...' if $self->debug;
+								print "Option 1: use_module( M::N )...\n" if $self->debug;
 								$self->_module_names_ppi_sl(\@modules, $ppi_sl);
 							}
 						}
@@ -162,8 +162,7 @@ sub xtests_use_module {
 							my $ppi_sl = $chunk->{children}[$_]
 								if $chunk->{children}[$_]->isa('PPI::Structure::List');
 
-							say
-								'Option 2: my $q = use_module( M::N )...' if $self->debug;
+							print "Option 2: my \$q = use_module( M::N )...\n" if $self->debug;
 							$self->_module_names_ppi_sl(\@modules, $ppi_sl);
 
 						}
@@ -246,8 +245,7 @@ sub xtests_use_module {
 									my $ppi_sl = $chunk->{children}[$_]
 										if $chunk->{children}[$_]->isa('PPI::Structure::List');
 
-									say
-										'Option 3: $q = use_module( M::N )...' if $self->debug;
+									print "Option 3: \$q = use_module( M::N )...\n" if $self->debug;
 									$self->_module_names_ppi_sl(\@modules, $ppi_sl);
 								}
 							}
@@ -339,7 +337,7 @@ sub xtests_use_module {
 						if ($chunk->{children}[$_]->isa('PPI::Structure::List')) {
 							my $ppi_sl = $chunk->{children}[$_]
 								if $chunk->{children}[$_]->isa('PPI::Structure::List');
-							say 'Option 4: return use_module( M::N )...' if $self->debug;
+							print "Option 4: return use_module( M::N )...\n" if $self->debug;
 							$self->_module_names_ppi_sl(\@modules, $ppi_sl);
 
 						}
@@ -354,18 +352,15 @@ sub xtests_use_module {
 
 	# if we found a module, process it with the correct catogery
 	if (scalar @modules > 0) {
-		if ($storage_location eq 'runtime_recommends') {
-			if ($self->format =~ /cpanfile|metajson/) {
-				$self->_process_found_modules('runtime_recommends', \@modules);
-
+			if ($self->meta2) {
+				$self->_process_found_modules($phase_relationship, \@modules, __PACKAGE__);
 			}
 			else {
-				$self->_process_found_modules('package_requires', \@modules);
+			$self->_process_found_modules('TestSuggests', \@modules, __PACKAGE__) if $self->xtest;
+			$self->_process_found_modules('RuntimeRequires', \@modules,
+				__PACKAGE__) if not $self->xtest;
+
 			}
-
-		}
-
-#		$self->_process_found_modules('package_requires', \@modules);
 	}
 	return;
 }
@@ -415,7 +410,7 @@ sub _module_names_ppi_sl {
 
 	if ($ppi_sl->isa('PPI::Structure::List')) {
 
-		state $previous_module = undef;
+		static \ my $previous_module;
 		foreach my $ppi_se (@{$ppi_sl->{children}}) {
 			for ( 0..$#{$ppi_se->{children}}) {
 
@@ -440,13 +435,7 @@ sub _module_names_ppi_sl {
 					$version_string =~ s/(?:['|"])//g;
 					next if $version_string !~ m/\A[\d|v]/;
 
-
-					try {
-						version->parse($version_string)->is_lax;
-					}
-					catch {
-						$version_string = 0 if $_;
-					};
+					$version_string = version::is_lax($version_string) ? $version_string : 0;
 
 					warn 'found version_string - ' . $version_string if $self->debug;
 					try {
@@ -481,7 +470,7 @@ includes, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.28
+version: 0.30
 
 
 =head1 METHODS
