@@ -1,19 +1,20 @@
 package App::Midgen::Role::UseOk;
 
-use v5.10;
-use Moo::Role;
-requires qw( ppi_document debug format xtest _process_found_modules develop );
+use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
 
-use PPI;
-use version 0.9902;
-use Try::Tiny 0.12;
-use Data::Printer {caller_info => 1, colored => 1,};
+use Moo::Role;
+requires qw( ppi_document debug format xtest _process_found_modules develop meta2 );
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.28';
-use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
+our $VERSION = '0.30';
+$VERSION = eval $VERSION; ## no critic
+
+use PPI;
+use Try::Tiny;
+use Data::Printer {caller_info => 1, colored => 1,};
+use Tie::Static qw(static);
 
 
 #######
@@ -21,6 +22,7 @@ use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
 #######
 sub xtests_use_ok {
 	my $self = shift;
+	my $phase_relationship = shift || NONE;
 
 	#PPI::Document
 	#  PPI::Statement::Scheduled
@@ -68,7 +70,7 @@ sub xtests_use_ok {
 										foreach my $element (@{$ppi_se->{children}}) {
 
 											# some fudge to remember the module name if falied
-											state $previous_module = undef;
+											static \ my $previous_module;
 											if ( $element->isa('PPI::Token::Quote::Single')
 												|| $element->isa('PPI::Token::Quote::Double'))
 											{
@@ -96,12 +98,7 @@ sub xtests_use_ok {
 												$version_string =~ s/['|"]$//;
 												next if $version_string !~ m/\A[\d|v]/;
 
-												try {
-													version->parse($version_string)->is_lax;
-												}
-												catch {
-													$version_string = 0 if $_;
-												};
+												$version_string = version::is_lax($version_string) ? $version_string : 0;
 
 												warn 'found version_string - ' . $version_string
 													if $self->debug;
@@ -129,16 +126,11 @@ sub xtests_use_ok {
 	# if we found a module, process it with the correct catogery
 	if (scalar @modules > 0) {
 
-		if ($self->format =~ /cpanfile|metajson/) {
-			if ($self->xtest eq 'test_requires') {
-				$self->_process_found_modules('test_requires', \@modules);
-			}
-			elsif ($self->develop && $self->xtest eq 'test_develop') {
-				$self->_process_found_modules('test_develop', \@modules);
-			}
+		if ($self->xtest) {
+			$self->_process_found_modules('DevelopRequires', \@modules, __PACKAGE__ );
 		}
 		else {
-			$self->_process_found_modules('test_requires', \@modules);
+			$self->_process_found_modules('TestRequires', \@modules, __PACKAGE__ );
 		}
 	}
 	return;
@@ -161,7 +153,7 @@ for methods in use_ok in BEGIN blocks, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.28
+version: 0.30
 
 =head1 METHODS
 
